@@ -2,6 +2,9 @@
 extern crate log;
 extern crate pretty_env_logger;
 
+use structopt::StructOpt;
+
+mod cli;
 mod duplicates;
 mod files;
 mod hashing;
@@ -9,6 +12,8 @@ mod model;
 
 fn main() {
     pretty_env_logger::init();
+    let arguments = cli::Arguments::from_args();
+    debug!("The command line arguments provided are {:?}.", arguments);
 
     let raw_files = crate::files::get_files_in_current_directory();
     let files = crate::model::to_file_content(raw_files);
